/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <alo17@hot.ee>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef __GNUG__
	#pragma implementation "PreferencesDlg.cpp"
#endif

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "PreferencesDlg.h"

BEGIN_EVENT_TABLE(CPreferencesDlg,wxDialog)
	EVT_BUTTON( ID_OK, CPreferencesDlg::OnOk )
	EVT_BUTTON( ID_CANCEL, CPreferencesDlg::OnCancel )
	EVT_LIST_ITEM_SELECTED(ID_PREFSCTRL, CPreferencesDlg::ChangePage)
END_EVENT_TABLE()

/*
 * Constructor for PreferencesDlg. Displays the dialog, centres it and sets
 * up images for the notebook.
 */
CPreferencesDlg::CPreferencesDlg( 
	wxWindow *parent, wxWindowID id, 
	const wxString &title, const wxPoint &position, const wxSize& size, 
	long style 
) : wxDialog( parent, id, title, position, size, style ) {
	
	DLG_PREFERENCES_LIST(this, true, true);
	SetupPrefsList();
	SetSize(500, 500);
	Centre();
	wxIcon prefs_icon;
	prefs_icon.CopyFromBitmap(PrefsIcons(0));
	SetIcon(prefs_icon);
	DLG_PPG_GENERAL(prefs_panel, true, true);

}

/*
 * Handles Ok button clicked event. Saves the settings and closes the dialog.
 */
void CPreferencesDlg::OnOk(wxCommandEvent &event) {
	EndModal(0);
}

/*
 * Handles Cancel button clicked event. Closes the dialog w/o saving settings.
 */
void CPreferencesDlg::OnCancel(wxCommandEvent &event) {
	EndModal(0);
}

/*
 * Inserts items into the Preferences dialog and sets correct images.
 */
void CPreferencesDlg::SetupPrefsList() {
	wxString m_text[] = {	
		wxT("General"), wxT("Display"), wxT("Connection"), wxT("Proxy"),
		wxT("Server"), wxT("Directories"), wxT("Files"), 
		wxT("Notifications"), wxT("Statistics"), wxT("IRC"), 
		wxT("Security"), wxT("Scheduler"), wxT("Web Interface"), 
		wxT("Tweaks")
	};

	wxImageList *m_prefsimages = new wxImageList(16, 16);
	for (int i=0; i<14; i++) {
		m_prefsimages->Add(PrefsIcons(i));
	}
	prefs_ctrl->AssignImageList(m_prefsimages, wxIMAGE_LIST_SMALL);
	prefs_ctrl->InsertColumn(0, wxT(""), wxLIST_FORMAT_LEFT, 
				prefs_ctrl->GetSize().GetWidth()-5);
	for (int i=0; i<14; i++) {
		prefs_ctrl->InsertItem(i, m_text[i], i);
	}
}

/*
 * Handles Prefs ListCtrl item selected event. Changes the contents of 
 * Prefs Panel.
 */ 
void CPreferencesDlg::ChangePage(wxListEvent &event) {
	Freeze();
	prefs_panel->Destroy();
	wxPanel *item3 = new wxPanel( this, ID_PREFSPANEL, wxDefaultPosition, wxDefaultSize, 0 );
	prefs_sizer->Add( item3, 0, wxGROW|wxALL, 5 );
	switch (event.GetIndex()) {
		case 0: DLG_PPG_GENERAL(prefs_panel, true, true);
			break;
		case 1: DLG_PPG_DISPLAY(prefs_panel, true, true);
			break;
		case 2: DLG_PPG_CONNECTION(prefs_panel, true, true);
			break;
		case 3: DLG_PPG_PROXY(prefs_panel, true, true);
			break;
		case 4: DLG_PPG_SERVER(prefs_panel, true, true);
			break;
		case 5: DLG_PPG_DIRECTORIES(prefs_panel, true, true);
			break;
		case 6: DLG_PPG_FILES(prefs_panel, true, true);
			break;
		case 7: DLG_PPG_NOTIFICATIONS(prefs_panel, true, true);
			break;
		case 8: DLG_PPG_STATISTICS(prefs_panel, true, true);
			break;
		case 9: DLG_PPG_IRC(prefs_panel, true, true);
			break;
		case 10: DLG_PPG_SECURITY(prefs_panel, true, true);
			break;
		case 11: DLG_PPG_SCHEDULER(prefs_panel, true, true);
			break;
		case 12: DLG_PPG_WEB(prefs_panel, true, true);
			break;
		case 13: DLG_PPG_TWEAKS(prefs_panel, true, true);
			break;
		default: 
			break;
	}
	Layout();
	Thaw();
}
